# Yield Curve with Machine Learning

![PyPI](https://img.shields.io/pypi/v/yieldcurveml) [![PyPI - License](https://img.shields.io/pypi/l/yieldcurveml)](https://github.com/Techtonique/yieldcurveml/blob/main/LICENSE) [![Downloads](https://pepy.tech/badge/yieldcurveml)](https://pepy.tech/project/yieldcurveml)[![Documentation](https://img.shields.io/badge/documentation-is_here-green)](https://techtonique.github.io/yieldcurveml/)


## 0 - Install: 

### From GitHub

```bash
!pip install git+https://github.com/Techtonique/yieldcurve.git
```

## 1. Examples: 

See [examples](/examples)

## 2. References 

- [https://www.researchgate.net/publication/393794192_New_Short_Rate_Models_and_their_Arbitrage-Free_Extension_A_Flexible_Framework_for_Historical_and_Market-Consistent_Simulation](https://www.researchgate.net/publication/393794192_New_Short_Rate_Models_and_their_Arbitrage-Free_Extension_A_Flexible_Framework_for_Historical_and_Market-Consistent_Simulation)
- [https://www.researchgate.net/publication/392507059_Beyond_Nelson-Siegel_and_splines_A_model-_agnostic_Machine_Learning_framework_for_discount_curve_calibration_interpolation_and_extrapolation](https://www.researchgate.net/publication/392507059_Beyond_Nelson-Siegel_and_splines_A_model-_agnostic_Machine_Learning_framework_for_discount_curve_calibration_interpolation_and_extrapolation)
